import {Component, OnInit} from '@angular/core';
import {DataService} from "./services/data.service";
import {Router} from "@angular/router";
import {MatSnackBar} from "@angular/material/snack-bar";


@Component({
  selector: 'slf-root',
  templateUrl: './app.component.html',
  styleUrls: ['./app.component.scss']
})
export class AppComponent implements OnInit {
  public databaseName?: string;

  constructor(
    private readonly router: Router,
    private readonly snackBar: MatSnackBar,
    private readonly dataService: DataService
  ) {
  }

  public ngOnInit(): void {
    this.dataService.getDatabaseInfo()
      .subscribe(info => this.databaseName = info.name);
  }

  public onFamilySearch(toSearch: string): void {
    toSearch = toSearch.toLowerCase();
    this.dataService.listFamilyNames()
      .subscribe(familyNames => {
        let matchingSpecies: string | string[] = familyNames.filter(name => name.toLowerCase().includes(toSearch));

        if (matchingSpecies.length === 0) {
          this.snackBar.open(`Unknown family: ${toSearch}`, 'Close', {
            horizontalPosition: "end",
            verticalPosition: "bottom",
            duration: 4000
          });
        }

        matchingSpecies = matchingSpecies[0];

        this.router.navigateByUrl('/', {skipLocationChange: true})
          .then(() => this.router.navigate(['family', matchingSpecies]));
      });
  }
}
